// coding: utf-8
/*! Created by: Udo Schmal | https://www.gocher.me/ */
(function () {
  'use strict';
  // global error event listener
  window.addEventListener('error', function (event) {
    try {
      var xhr = new XMLHttpRequest();
      if (xhr) {
        xhr.onreadystatechange = function () {};
        xhr.open('POST', "/error.json");
        xhr.setRequestHeader("Content-Type", "application/json;charset=UTF-8");
        xhr.send(JSON.stringify({
          useragent: navigator.userAgent,
          path: window.location.href,
          message: event.message,
          filename: event.filename,
          lineno: event.lineno,
          colno: event.colno,
          error: JSON.stringify(event.error)}));
      }
    } catch (e1) { };
  });

  function loadScript(href, callback, async) {
    if (async === undefined) {
      async = true;
    }
    var id = href.split('\\').pop().split('/').pop();
    if (!document.getElementById(id)) {
      var script = document.createElement('script');
      script.id = id;
      script.src = href;
      if (async) {
        script.async = true;
        script.defer = true;
      }
      if (callback) {
        script.addEventListener('load', callback);
      }
      document.body.appendChild(script);
    }
  }

  function loadStyle(href) {
    var id = href.split('\\').pop().split('/').pop();
    if (!document.getElementById(id)) {
      var style = document.createElement('link');
      style.id = id;
      style.type = 'text/css';
      style.rel = 'stylesheet';
      style.href = href;
      document.head.appendChild(style);
    }
  }

  // secure schema json
  var schema = {
    "@context": "https://schema.org/",
    "@type": "Organization",
    "name": "Gocher.Me",
    "logo": "https://www.gocher.me/icon~192x192.png",
    "url": "https://www.gocher.me/",
    "telephone": "+4915750663676",
    "sameAs" : [
      "https://www.instagram.com/udo.schmal/"
    ],
    "address": {
      "@type": "PostalAddress",
      "streetAddress": "Ellerndiek 26",
      "addressRegion": "Schleswig",
      "postalCode": "24837",
      "addressCountry": "DE"
    },
    "geo": {
      "@type": "GeoCoordinates",
      "latitude": 54.499864,
      "longitude": 9.532111
    }
  };
  var o = document.createElement('script');
  o.type = 'application/ld+json';
  o.innerHTML = JSON.stringify(schema);
  document.head.appendChild(o);
  // article download and sharing
  var article = document.querySelector('article');
  if (article) {
    // add article buttons
    var div = document.createElement('div');
    div.setAttribute('class', 'articleButtons');
    article.insertBefore(div, article.firstChild);
    function createLink(className, title, ext) {
      let path = (window.location.pathname == '/' ? '/index' : window.location.pathname);
      let a = document.createElement('a');
      a.className = className;
      a.setAttribute('title', title);
      a.href = path + ext;
      a.setAttribute('target', '_blank');
      a.setAttribute('rel', 'nofollow');
      div.appendChild(a);
    }
    createLink('file-pdf', 'als PDF herunterladen', '.pdf');
    createLink('file-rtf', 'als RTF herunterladen', '.rtf');
    createLink('file-tex', 'als LaTeX herunterladen', '.tex');
    createLink('file-html5', 'als HTML herunterladen', '.html');
    if (!document.querySelector('div.gallery')) {
      createLink('file-archive', 'als Zip-Archiv herunterladen', '.zip');
    }
    createLink('file-txt', 'als Text herunterladen', '.txt');
    let button = document.createElement('button');
    button.setAttribute('type', 'button');
    button.className = 'print';
    button.setAttribute('title', 'drucken');
    button.addEventListener('click', function () { window.print(); });
    div.appendChild(button);
    // add share buttons
    div = document.createElement('div');
    div.setAttribute('id', 'socialbookmarks');
    article.appendChild(div);
    var p = document.createElement('p');
    div.appendChild(p);
    let span = document.createElement('span');
    span.className = 'label';
    span.appendChild(document.createTextNode('teile es: '));
    p.appendChild(span);
    function createSocialBookmarkLink(className, title, href) {
      let a = document.createElement('a');
      a.className = 'socialbookmark ' + className;
      a.setAttribute('title', title);
      a.setAttribute('target', '_blank');
      a.href = href;
      p.appendChild(a);
    }
    function createSocialBookmarkButton(className, title, ev) {
      let button = document.createElement('button');
      button.setAttribute('type', 'button');
      button.className = 'socialbookmark ' + className;
      button.setAttribute('title', title);
      button.addEventListener('click', ev);
      p.appendChild(button);
    }
    let href = encodeURIComponent(location.href);
    let title = encodeURIComponent(document.title);
    createSocialBookmarkLink('whatsapp', 'WhatsApp', 'https://wa.me/?text=' + href);
    createSocialBookmarkLink('twitter', 'X/Twitter', 'https://twitter.com/intent/tweet?url=' + href + '&text=' + title);
    createSocialBookmarkLink('facebook', 'Facebook', 'https://www.facebook.com/sharer/sharer.php?u=' + href + '&title=' + title);
    createSocialBookmarkLink('xing', 'Xing', 'https://www.xing.com/spi/shares/new?url=' + href + '&text=' + title);
    createSocialBookmarkLink('pinterest', 'Pinterest', 'https://pinterest.com/pin/create/button/?url=' + href);
    createSocialBookmarkLink('email', 'Email', 'mailto:?subject=Meldung%20auf%20' + location.hostname + '&body=' + href);
    /*var img = document.querySelector('meta[property="og:image"]');
    createSocialBookmark('pinterest', 'Pinterest', 'https://pinterest.com/pin/create/button/?url=' + href + '&description=' + title + '&media=' + encodeURIComponent(img));*/
    // add native share
    if (navigator.share) {
      createSocialBookmarkButton('native', 'Mobile native', function () {
        navigator.share({title: document.title, text: '', url: location.href });
      });
    }
    // hyphenate text
    article.classList.add("hyphenate");
  }

  // disable mobile services
  if (!/Android|webOS|iPhone|iPad|iPod|BlackBerry|Mobile|Opera Mini/i.test(navigator.userAgent)) {
    //if ('contacts' in navigator && 'ContactsManager' in window)
    let a = document.querySelectorAll('span.whatsapp-enable');
    for (let i = 0; i < a.length; i++) {
      a[i].style.display = 'none';
    }
    //if ('sms' in navigator)
    a = document.querySelectorAll('span.sms-enable');
    for (let i = 0; i < a.length; i++) {
      a[i].style.display = 'none';
    }
  }

  // add boxes like copyright
  var boxes = document.querySelector('#content-container > .boxes-container');
  if (boxes) {
    function createBox(title) {
      let boxArea = document.createElement('div');
      boxArea.className = 'box-area';
      let box = document.createElement('div');
      box.className = 'box';
      boxArea.appendChild(box);
      let boxHead = document.createElement('div');
      boxHead.className = 'box-head';
      box.appendChild(boxHead);
      let h = document.createElement('h4');
      h.appendChild(document.createTextNode(title));
      boxHead.appendChild(h);
      let boxContent = document.createElement('div');
      boxContent.className = 'box-content';
      box.appendChild(boxContent);
      let boxBody = document.createElement('div');
      boxBody.className = 'box-body';
      boxContent.appendChild(boxBody);
      if (boxes.hasChildNodes()) {
        boxes.insertBefore(boxArea, boxes.firstChild);
      } else {
        boxes.appendChild(boxArea);
      }
      return boxBody;
    }

    if (document.querySelector('a.code') || document.querySelector('code')) {
      let boxBody = createBox('Copyright / License of sources');
      let p = document.createElement('p');
      let now = new Date(), year = now.getFullYear();
      p.appendChild(document.createTextNode('Copyright (c) 2007-' + year + ', Udo Schmal <'));
      let a = document.createElement('a');
      a.setAttribute('href', 'mailto:udo.schmal@t-online.de');
      a.appendChild(document.createTextNode('udo.schmal@t-online.de'));
      p.appendChild(a);
      p.appendChild(document.createTextNode('>'));
      boxBody.appendChild(p);
      p = document.createElement('p');
      p.appendChild(document.createTextNode('Permission to use, copy, modify, and/or distribute the software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.'));
      boxBody.appendChild(p);
      p = document.createElement('p');
      p.appendChild(document.createTextNode('THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.'));
      boxBody.appendChild(p);
    }
    if (document.querySelector('ul.gallery') || document.querySelector('a.hires')) {
      let boxBody = createBox('Bildrechte');
      let p = document.createElement('p');
      p.appendChild(document.createTextNode('Alle auf dieser Website veröffentlichen Bilder dürfen ausschließlich durch Freunde privat genutzt werden, weitere Infos siehe unter '));
      let a = document.createElement('a');
      a.setAttribute('href', '/Impressum');
      a.appendChild(document.createTextNode('Impressum'));
      p.appendChild(a);
      p.appendChild(document.createTextNode('!'));
      boxBody.appendChild(p);
    }
  }

  // trauer Sammy
  var header = document.getElementById('header');
  let ribbon = document.createElement('span');
  ribbon.className = 'ribbon';
  ribbon.appendChild(document.createTextNode('✞ 03.05.2022'));
  ribbon.addEventListener('click', function () {location.href='/Sammy';});
  header.appendChild(ribbon);

  // load observer polyfill
  if (!document.getElementById('observer.js') && (!('IntersectionObserver' in window) || !('ResizeObserver' in window))) {
    loadScript('/scripts/observer.js');
  }

  // load application script
  if ((location.protocol == 'https:') && (screen.width > 0)) {
    loadScript('/scripts/app.js');
  } else {
    // get SessionID
    var SessionID = '';
    const value = document.cookie;
    SessionID = value.split('__Host-SessionID=');
    if (SessionID.length === 2) {
      SessionID = SessionID.pop().split(';').shift();
    }
    if (SessionID != localStorage.getItem('__Host-SessionID')) {
      // on new session sent screen/display values
      var xhr = new XMLHttpRequest();
      xhr.open("POST", "/xhr.json", true);
      xhr.setRequestHeader("Content-Type", "application/json;charset=UTF-8");
      //xhr.responseType = 'json';
      xhr.addEventListener('load', function (event) {
        if (xhr.status === 200) {
          //localStorage.clear();
          var response = JSON.parse(xhr.responseText);
          localStorage.setItem('__Host-rights', 'none');
          if (response) {
            localStorage.setItem('__Host-SessionID', response['__Host-SessionID']);
          }
        }
      });
      xhr.send(
        JSON.stringify({
          width: screen.width,
          height: screen.height,
          density: ((typeof(window.devicePixelRatio) != "undefined") ? window.devicePixelRatio : 1)
        })
      );
    }
  }

  // loading lazy
  loadScript('/scripts/viewport.js');
  // add position: sticky fallback
  var el = document.querySelector('[data-type="sticky"]');
  if (el) {
    el.style.position = 'sticky';
    if (window.getComputedStyle(el).getPropertyValue("position") != "sticky") {
      loadScript('/scripts/sticky.js');
    }
  }
  // javascript fallbacks for unsupported css property scroll-behavior: smooth fallback
  if (!('scrollBehavior' in document.documentElement.style)) {
    loadScript('/scripts/smoothscroll.js');
  }
  //*** remove this part on merge scripts
  if (document.querySelector('img[class~="focus"]')) {
    loadScript('/scripts/focus.js');
  }
  if (document.querySelector(".tabsheets")) {
    loadScript('/code/tabsheets/tabsheets.js');
  }
  if (document.querySelector(".accordion")) {
    loadScript('/code/accordion/accordion.js');
  }
  if (document.querySelector(".pages")) {
    loadScript('/code/pagination/pages.js');
  }
  //if (document.querySelector(".slider")) {
    loadScript('/code/slider/slider.js');
  //}
  let hires = document.querySelector('a.hires');
  let galleryImages = document.querySelector('ul.gallery a');
  if (hires || galleryImages) {
    loadScript('/scripts/lightbox.js');
    //loadScript('/code/gallery/gallery.js');
  }
  // ***//

  // touch device abbr handling
    var useCapture = false;
    try {
      var opts = Object.defineProperty({}, 'passive', {
        get: function() {
          useCapture = {capture: false, passive: true};
        }
      });
      window.addEventListener("testPassive", null, opts);
      window.removeEventListener("testPassive", null, opts);
    } catch (e) {}
    var abbr = document.querySelectorAll('abbr');
    //var abbrDiv;
    //function removeAbbrDiv(event) {
    //  document.body.removeChild(abbrDiv);
    //  event.target.removeEventListener('blur', removeAbbrDiv);
    //}
    function addAbbrDiv(event) {
      //this.setAttribute('tabindex', '0');
      //this.focus();
      if (this.getAttribute('title') != '') {
        var abbrDiv = document.createElement('div');
        abbrDiv.className = 'abbr';
        abbrDiv.appendChild(document.createTextNode(this.getAttribute('title')));
        document.body.appendChild(abbrDiv);
        abbrDiv.style.left = event.touches[0].pageX + 'px';
        abbrDiv.style.top = event.touches[0].pageY + 'px';
        var rect = abbrDiv.getBoundingClientRect();
        if (window.innerWidth < rect.right) {
          abbrDiv.style.right = '0px';
          abbrDiv.style.left = 'auto';
        }
        setTimeout(function(){
          document.body.removeChild(abbrDiv);
        }, 3000);
        //this.addEventListener('blur', removeAbbrDiv);
      }
    }
    for (var i=0; i < abbr.length; i++) {
      abbr[i].addEventListener('touchstart', addAbbrDiv, useCapture);
    }

  /* toggle hamburger menu */
  let btn = document.getElementById("menu-btn");
  if (btn) {
    let language = document.documentElement.lang || 'en';
    btn = btn || document.getElementById('menu-btn');
    if (btn) {
      const nav = document.getElementById('nav-container'),
        lang = language.substr(0, 2),
        txtShowMenu = (lang == 'de' ? 'Menü anzeigen' : 'show menu'),
        txtHideMenu = (lang == 'de' ? 'Menü ausblenden' : 'hide menu');
      function setStatus () {
        if (btn.classList.contains('active')) {
          btn.setAttribute('title', txtHideMenu);
          document.body.addEventListener('click', toggle);
        } else {
          btn.setAttribute('title', txtShowMenu);
          document.body.removeEventListener('click', toggle);
        }
      }
      function toggle (event) {
        if (event.target.id == 'menu-btn' || event.target.parentNode.id == 'menu-btn') {
          event.preventDefault();
          event.stopPropagation();
        }
        btn.classList.toggle('active');
        if (nav) {
          if (nav.classList.contains('active')) {
            nav.classList.remove('active');
            nav.classList.add('inactive');
          } else{
            nav.classList.remove('inactive');
            nav.classList.add('active');
          }
        }
        setStatus();
      }
      btn.addEventListener('click', toggle);
      setStatus();
    }
  }

  /* toggle tr childs */
  let trparents = document.querySelectorAll("tr.parent");
  function toggleTrChilds(event) {
    function nextRow(row) {
      while ((row = row.nextSibling) && row.nodeType != 1);
      return row;
    }
    var row = this;
    while ((row = nextRow(row)) && !row.classList.contains("parent")) {
      row.classList.toggle("open");
    }
  }
  for (let i = 0; i < trparents.length; i++) {
    el [i].addEventListener('click', toggleTrChilds);
  }

  /* unsafe-inline fix */
  let uif = document.querySelectorAll("[data-style-width]");
  for (let i = 0; i < uif.length; i++) {
    uif[i].style.width = uif[i].getAttribute('data-style-width');
  }

  /* navi */
  function keydown(event) {
    let root = event.target.parentNode.parentNode.parentNode.tagName.toLowerCase() === 'nav';
    switch (event.key) {
      case 'Home':
        let firstLi = event.target.parentNode.parentNode.firstElementChild;
        if (firstLi) {
          // first item
          let a = firstLi.querySelector('a');
          if (a) {
            a.focus();
          }
        }
        event.preventDefault();
        event.stopPropagation();
        break;
      case 'End':
        let lastLi = event.target.parentNode.parentNode.lastElementChild;
        if (lastLi) {
          let a = lastLi.querySelector('a');
          if (a) {
            a.focus();
          }
        }
        event.preventDefault();
        event.stopPropagation();
        break;
      case 'ArrowDown':
        // main menu first child item
        if (root) {
          let ul = event.target.parentNode.getElementsByTagName("ul");
          if (ul && ul.length > 0) {
            // first subnavigation item
            let a = ul[0].querySelector('li > a');
            if (a) {
              a.focus();
            }
          }
        } else {
          let nextLi = event.target.parentNode.nextElementSibling;
          if (nextLi) {
            // next subnavigation item
            let a = nextLi.querySelector("a");
            if (a) {
              a.focus();
            }
          } else {
            // next parent level item
            let a = event.target.parentNode.parentNode.parentNode.nextElementSibling.querySelector('a');
            if (a) {
              a.focus();
            }
          }
        }
        event.preventDefault();
        event.stopPropagation();
        break;
      case 'ArrowUp':
      case 'ArrowLeft':
        if (root) {
          // parent level item
          let prevLi = event.target.parentNode.previousElementSibling;
          if (prevLi) {
            let a = prevLi.querySelector("a");
            if (a) {
              a.focus();
            }
          }
        } else {
          let prevLi = event.target.parentNode.previousElementSibling;
          if (prevLi && event.key !== 'ArrowLeft') {
            // previous subnavigation item
            let a = prevLi.querySelector("a");
            if (a) {
              a.focus();
            }
          } else {
            // parent level item
            let a = event.target.parentNode.parentNode.previousElementSibling;
            if (a) {
              a.focus();
            }
          }
        }
        event.preventDefault();
        event.stopPropagation();
        break;
      case 'ArrowRight':
      case ' ':
        // main menu next item
        if (root) {
          let nextLi = event.target.parentNode.nextElementSibling;
          if (nextLi) {
            // next main navigation item
            let a = nextLi.querySelector('a');
            if (a) {
              a.focus();
            }
          }
        } else {
          // submenu next level
          let ul = event.target.parentNode.getElementsByTagName('ul');
          if (ul && ul.length > 0) {
            ul[0].style.display = 'block';
            let a = ul[0].querySelector('li > a');
            if (a) {
              a.focus();
            }
            ul[0].style.display = '';
          }
        }
        event.preventDefault();
        event.stopPropagation();
        break;
    }
  }

  let navEls = document.querySelectorAll("nav#nav > ul > li");
  for (let i = 0; i < navEls.length; i++) {
    let subNav = navEls[i].getElementsByTagName("ul");
    if (subNav && subNav.length > 0) {
      let a = subNav[0].getElementsByTagName("a");
      for (let o = 0; o < a.length; o++) {
        // set tabindex to -1 to exclude all subnavigation links from tabindex
        a[o].setAttribute('tabindex', '-1');
        // subnavigation eventlistener support for ArrowDown and ArrowUp
        a[o].addEventListener('keydown', keydown);
      }
    }
    // add even listener keydown to main nav entries
    navEls[i].addEventListener('keydown', keydown);
  }

  /* handle external link */
  function externalLink(event) {
    event.preventDefault();
    let href = this.href;
    let domain = /https?:\/\/([^\/]*)/i.exec(href)[1];
    var overlay = document.createElement('div');
    overlay.className = 'overlay';
    document.body.appendChild(overlay);

    let dialog = document.createElement('div');
    dialog.classList.add('dialog');
    dialog.classList.add('external-link');
    overlay.appendChild(dialog);

    let header = document.createElement('div');
    header.classList.add('header');
    let h = document.createElement('h3');
    h.appendChild(document.createTextNode('Inhalt auf exterener Seite'));
    header.appendChild(h);
    let close = document.createElement('button');
    close.classList.add('close');
    close.appendChild(document.createTextNode('×'));
    header.appendChild(close);
    dialog.appendChild(header);

    let content = document.createElement('div');
    content.classList.add('content');
    let p = document.createElement('p');
    p.appendChild(document.createTextNode('Sie werden weitergeleitet zu:'));
    p.appendChild(document.createElement('br'));
    p.appendChild(document.createTextNode(domain));
    content.appendChild(p);
    dialog.appendChild(content);

    let footer = document.createElement('div');
    footer.classList.add('footer');
    let no =  document.createElement('button');
    no.setAttribute('type', 'button');
    no.classList.add('no');
    no.appendChild(document.createTextNode('Abbrechen'));
    footer.appendChild(no);
    let yes = document.createElement('button');
    yes.setAttribute('type', 'button');
    yes.classList.add('yes');
    yes.appendChild(document.createTextNode('Weiter'));
    footer.appendChild(yes);
    dialog.appendChild(footer);

    function closeDialog() {
      document.body.removeChild(overlay);
    }
    close.addEventListener('click', closeDialog);
    no.addEventListener('click', closeDialog);
    yes.addEventListener('click', function () { closeDialog(); window.open(href, '_blank').focus();});
  }

  let refs = document.querySelectorAll("a[href]");
  if (refs.length > 0) {
    let host = window.location.host;
    for (let i = 0; i < refs.length; i++) {
      let href = refs[i].getAttribute('href');
      let hit = /https?:\/\/([^\/]*)/i.exec(href);
      if (hit && hit[1]) {
        if (host != hit[1]) {
          // console.log(href, hit[1]);
          refs[i].addEventListener('click', externalLink);
        }
      }
    }
  }

})();
